You are viewing a plain text version of this content. The canonical link for it is here.
Posted to notifications@libcloud.apache.org by to...@apache.org on 2021/11/12 21:02:33 UTC

[libcloud] 02/03: Instead of comparing md5 sum, compare sha512 sum instead.

This is an automated email from the ASF dual-hosted git repository.

tomaz pushed a commit to branch trunk
in repository https://gitbox.apache.org/repos/asf/libcloud.git

commit 37a28720142927fef22f9828730fbb1438151139
Author: Tomaz Muraus <to...@tomaz.me>
AuthorDate: Thu Nov 11 21:00:38 2021 +0100

    Instead of comparing md5 sum, compare sha512 sum instead.
---
 dist/verify_checksums.sh | 16 ++++++++--------
 1 file changed, 8 insertions(+), 8 deletions(-)

diff --git a/dist/verify_checksums.sh b/dist/verify_checksums.sh
index 90357b5..c58339b 100755
--- a/dist/verify_checksums.sh
+++ b/dist/verify_checksums.sh
@@ -15,7 +15,7 @@
 # limitations under the license.
 
 # This script downloads release artifacts from Apache server and PyPi server and
 # verifies that the MD5 checksum of both archives matches.
 
 VERSION=$1
 
@@ -110,17 +110,17 @@ do
         exit 2
     fi
 
-    md5sum_apache=$(md5sum "${file_path_apache}" | awk '{ print $1 }')
-    md5sum_pypi=$(md5sum "${file_path_pypi}"| awk '{ print $1 }')
+    sha512sum_apache=$(sha512sum "${file_path_apache}" | awk '{ print $1 }')
+    sha512sum_pypi=$(sha512sum "${file_path_pypi}"| awk '{ print $1 }')
 
-    if [ ${md5sum_apache} != ${md5sum_pypi} ]; then
-       echo "[ERROR] MD5 sum for file ${file_name} doesn\'t match"
+    if [ ${sha512sum_apache} != ${sha512sum_pypi} ]; then
+       echo "[ERROR] SHA512 sum for file ${file_name} doesn\'t match"
        echo ""
-       echo "${file_name_apache}: ${md5sum_apache}"
-       echo "${file_name_pypi}: ${md5sum_pypi}"
+       echo "${file_name_apache}: ${sha512sum_apache}"
+       echo "${file_name_pypi}: ${sha512sum_pypi}"
        exit 1
    else
-       echo "[OK] MD5 sum for file ${file_name} matches"
+       echo "[OK] SHA512 sum for file ${file_name} matches"
     fi
 
     echo ""
@@ -15,7 +15,7 @@
 
 # This script downloads release artifacts from Apache server and PyPi server and
-# verifies that the MD5 checksum of both archives matches.
+# verifies that the SHA512 checksum of both archives matches.
 
 VERSION=$1